@@ -631,6 +631,8 @@ our $dispatch_map = {
     "EMPLOYEE_SPEC PRIV_SPEC EFFECTIVE _DATE" => \&add_priv_history,
     "EMPLOYEE_SPEC SCHEDULE_SPEC _DATE" => \&add_schedule_history,
     "EMPLOYEE_SPEC SCHEDULE_SPEC EFFECTIVE _DATE" => \&add_schedule_history,
+    "EMPLOYEE_SPEC SID" => \&noop,
+    "EMPLOYEE_SPEC SCODE" => \&noop,
     "EMPLOYEE_SPEC SET PRIV_SPEC _DATE" => \&add_priv_history,
     "EMPLOYEE_SPEC SET PRIV_SPEC EFFECTIVE _DATE" => \&add_priv_history,
     "EMPLOYEE_SPEC SET SCHEDULE_SPEC _DATE" => \&add_schedule_history,
